When the module was made, I was 17 and it was made for personnal uses and learning reasons so be indulgent.

In this module, you will be able to:

-preprocess data

-create neural networks

-visualize the evolution of the learning model

-retrieve all the data if needed (including all hyper parameters)